<?php
/*****************************************************************************
 *
 * pChartPieChart_1.php - Gadget for NagVis to diplay pie charts
 *
 * Copyright (c) 2004-2009 NagVis Project (Contact: lars@vertical-visions.de, michael_luebben@web.de)
 *
 * License:
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *****************************************************************************
 *
 * This is a simple gadget for NagVis. A gadget is a script which generates a
 * dynamic image for visualizing things as graphics in NagVis.
 *
 * The gadget gets its data from the NagVis frontend by parameters. This
 * gadget only needs the "perfdata" parameter. NagVis also passes the
 * following parameters to the gadgets:
 *  - name1:     Hostname
 *  - name2:     Service description
 *  - state:     Current state
 *  - stateType: Current state type (soft/hard)
 *
 *****************************************************************************/

// Load gadget core functions
require('./gadgets_core.php');

/*******************************************************************************
 * Start gadget main code
 ******************************************************************************/

header("Content-type: image/png");

//==========================================
// Set Minimum, Default, and Maximum values.
//==========================================

$min = 0;
$max = -1;
$default = 0; 
 
/* Now read the parameters */

$aOpts = Array('name1', 'name2', 'state', 'stateType', 'perfdata');
$aPerfdata = Array();

/**
 * Needed:
 *  perfdata=load1=0.960;5.000;10.000;0; load5=0.570;4.000;6.000;0; load15=0.540;3.000;4.000;0;
 *
 * Optional
 *  name1=localhost
 *  name2=Current Load
 *  state=OK
 *  stateType=HARD
 */

if(isset($_GET['perfdata']) && $_GET['perfdata'] != '') {
	$aOpts['perfdata'] = $_GET['perfdata'];
} else {
	errorBox('ERROR: The needed parameter "perfdata" is missing.');
}

if(isset($_GET['name1']) && $_GET['name1'] != '') {
	$aOpts['name1'] = $_GET['name1'];
}

if(isset($_GET['name2']) && $_GET['name2'] != '') {
	$aOpts['name2'] = $_GET['name2'];
}

if(isset($_GET['state']) && $_GET['state'] != '') {
	$aOpts['state'] = $_GET['state'];
}

if(isset($_GET['stateType']) && $_GET['stateType'] != '') {
	$aOpts['stateType'] = $_GET['stateType'];
}

/* Now parse the perfdata */
$aPerfdata = parsePerfdata($aOpts['perfdata']);

// This gadget is simple and dirty, it only recognizes the first dataset of
// performance data

$value = $aPerfdata[0]['value'];
$uom = $aPerfdata[0]['uom'];
$warn = $aPerfdata[0]['warning'];
$crit = $aPerfdata[0]['critical'];
$min = $aPerfdata[0]['min'];
$max = $aPerfdata[0]['max'];
$free = $max - $value;


// Draw pie chart and create image ouput
// Standard inclusions      
include("./pChart/pChart/pData.class");   
include("./pChart/pChart/pChart.class");   
  
// Dataset definition    
$DataSet = new pData;   
$DataSet->AddPoint(array($free,$value),"Serie1");   
$DataSet->AddPoint(array("Free","Used"),"Serie2");   
$DataSet->AddAllSeries();   
$DataSet->SetAbsciseLabelSerie("Serie2");   
  
// Initialise the graph   
$graph = new pChart(360,220);   
$graph->drawFilledRoundedRectangle(7,7,353,213,5,240,240,240);   
$graph->drawRoundedRectangle(5,5,355,215,5,230,230,230);   
 
// Draw the title   
$graph->setFontProperties("./pChart/Fonts/tahoma.ttf",9);
$Title = " \nDisk statistics for Host ".$aOpts['name1']." / ".$aOpts['name2']."  ";   
$graph->drawTextBox(10,10,350,40,$Title,0,255,255,255,ALIGN_TOP_CENTER,FALSE,0,0,0,30); 
 
// Draw the pie chart   
$graph->setFontProperties("./pChart/Fonts/tahoma.ttf",8);   
$graph->drawPieGraph($DataSet->GetData(),$DataSet->GetDataDescription(),150,115,110,PIE_PERCENTAGE,TRUE,50,20,5);   
$graph->drawPieLegend(290,105,$DataSet->GetData(),$DataSet->GetDataDescription(),250,250,250);   
  
$graph->stroke();
?>
